# pyright: reportUnusedImport=false
from . import abcs, types
from .core import Serializable, Reader, deserialize_bool, deserialize_i32_list, deserialize_i64_list, deserialize_identity, single_deserializer, list_deserializer
from typing import cast, Type
LAYER = 165
TYPE_MAPPING = {t.constructor_id(): t for t in cast(tuple[Type[Serializable]], (
  types.AccountDaysTtl,
  types.AppWebViewResultUrl,
  types.AttachMenuBot,
  types.AttachMenuBotIcon,
  types.AttachMenuBotIconColor,
  types.AttachMenuBots,
  types.AttachMenuBotsBot,
  types.AttachMenuBotsNotModified,
  types.AttachMenuPeerTypeBotPm,
  types.AttachMenuPeerTypeBroadcast,
  types.AttachMenuPeerTypeChat,
  types.AttachMenuPeerTypePm,
  types.AttachMenuPeerTypeSameBotPm,
  types.Authorization,
  types.AutoDownloadSettings,
  types.AutoSaveException,
  types.AutoSaveSettings,
  types.AvailableReaction,
  types.BankCardOpenUrl,
  types.BaseThemeArctic,
  types.BaseThemeClassic,
  types.BaseThemeDay,
  types.BaseThemeNight,
  types.BaseThemeTinted,
  types.Booster,
  types.BotApp,
  types.BotAppNotModified,
  types.BotCommand,
  types.BotCommandScopeChatAdmins,
  types.BotCommandScopeChats,
  types.BotCommandScopeDefault,
  types.BotCommandScopePeer,
  types.BotCommandScopePeerAdmins,
  types.BotCommandScopePeerUser,
  types.BotCommandScopeUsers,
  types.BotInfo,
  types.BotInlineMediaResult,
  types.BotInlineMessageMediaAuto,
  types.BotInlineMessageMediaContact,
  types.BotInlineMessageMediaGeo,
  types.BotInlineMessageMediaInvoice,
  types.BotInlineMessageMediaVenue,
  types.BotInlineMessageText,
  types.BotInlineResult,
  types.BotMenuButton,
  types.BotMenuButtonCommands,
  types.BotMenuButtonDefault,
  types.CdnConfig,
  types.CdnPublicKey,
  types.Channel,
  types.ChannelAdminLogEvent,
  types.ChannelAdminLogEventActionChangeAbout,
  types.ChannelAdminLogEventActionChangeAvailableReactions,
  types.ChannelAdminLogEventActionChangeHistoryTtl,
  types.ChannelAdminLogEventActionChangeLinkedChat,
  types.ChannelAdminLogEventActionChangeLocation,
  types.ChannelAdminLogEventActionChangePhoto,
  types.ChannelAdminLogEventActionChangeStickerSet,
  types.ChannelAdminLogEventActionChangeTitle,
  types.ChannelAdminLogEventActionChangeUsername,
  types.ChannelAdminLogEventActionChangeUsernames,
  types.ChannelAdminLogEventActionCreateTopic,
  types.ChannelAdminLogEventActionDefaultBannedRights,
  types.ChannelAdminLogEventActionDeleteMessage,
  types.ChannelAdminLogEventActionDeleteTopic,
  types.ChannelAdminLogEventActionDiscardGroupCall,
  types.ChannelAdminLogEventActionEditMessage,
  types.ChannelAdminLogEventActionEditTopic,
  types.ChannelAdminLogEventActionExportedInviteDelete,
  types.ChannelAdminLogEventActionExportedInviteEdit,
  types.ChannelAdminLogEventActionExportedInviteRevoke,
  types.ChannelAdminLogEventActionParticipantInvite,
  types.ChannelAdminLogEventActionParticipantJoin,
  types.ChannelAdminLogEventActionParticipantJoinByInvite,
  types.ChannelAdminLogEventActionParticipantJoinByRequest,
  types.ChannelAdminLogEventActionParticipantLeave,
  types.ChannelAdminLogEventActionParticipantMute,
  types.ChannelAdminLogEventActionParticipantToggleAdmin,
  types.ChannelAdminLogEventActionParticipantToggleBan,
  types.ChannelAdminLogEventActionParticipantUnmute,
  types.ChannelAdminLogEventActionParticipantVolume,
  types.ChannelAdminLogEventActionPinTopic,
  types.ChannelAdminLogEventActionSendMessage,
  types.ChannelAdminLogEventActionStartGroupCall,
  types.ChannelAdminLogEventActionStopPoll,
  types.ChannelAdminLogEventActionToggleAntiSpam,
  types.ChannelAdminLogEventActionToggleForum,
  types.ChannelAdminLogEventActionToggleGroupCallSetting,
  types.ChannelAdminLogEventActionToggleInvites,
  types.ChannelAdminLogEventActionToggleNoForwards,
  types.ChannelAdminLogEventActionTogglePreHistoryHidden,
  types.ChannelAdminLogEventActionToggleSignatures,
  types.ChannelAdminLogEventActionToggleSlowMode,
  types.ChannelAdminLogEventActionUpdatePinned,
  types.ChannelAdminLogEventsFilter,
  types.ChannelForbidden,
  types.ChannelFull,
  types.ChannelLocation,
  types.ChannelLocationEmpty,
  types.ChannelMessagesFilter,
  types.ChannelMessagesFilterEmpty,
  types.ChannelParticipant,
  types.ChannelParticipantAdmin,
  types.ChannelParticipantBanned,
  types.ChannelParticipantCreator,
  types.ChannelParticipantLeft,
  types.ChannelParticipantSelf,
  types.ChannelParticipantsAdmins,
  types.ChannelParticipantsBanned,
  types.ChannelParticipantsBots,
  types.ChannelParticipantsContacts,
  types.ChannelParticipantsKicked,
  types.ChannelParticipantsMentions,
  types.ChannelParticipantsRecent,
  types.ChannelParticipantsSearch,
  types.Chat,
  types.ChatAdminRights,
  types.ChatAdminWithInvites,
  types.ChatBannedRights,
  types.ChatEmpty,
  types.ChatForbidden,
  types.ChatFull,
  types.ChatInvite,
  types.ChatInviteAlready,
  types.ChatInviteExported,
  types.ChatInviteImporter,
  types.ChatInvitePeek,
  types.ChatInvitePublicJoinRequests,
  types.ChatOnlines,
  types.ChatParticipant,
  types.ChatParticipantAdmin,
  types.ChatParticipantCreator,
  types.ChatParticipants,
  types.ChatParticipantsForbidden,
  types.ChatPhoto,
  types.ChatPhotoEmpty,
  types.ChatReactionsAll,
  types.ChatReactionsNone,
  types.ChatReactionsSome,
  types.CodeSettings,
  types.Config,
  types.Contact,
  types.ContactStatus,
  types.DataJson,
  types.DcOption,
  types.DefaultHistoryTtl,
  types.Dialog,
  types.DialogFilter,
  types.DialogFilterChatlist,
  types.DialogFilterDefault,
  types.DialogFilterSuggested,
  types.DialogFolder,
  types.DialogPeer,
  types.DialogPeerFolder,
  types.Document,
  types.DocumentAttributeAnimated,
  types.DocumentAttributeAudio,
  types.DocumentAttributeCustomEmoji,
  types.DocumentAttributeFilename,
  types.DocumentAttributeHasStickers,
  types.DocumentAttributeImageSize,
  types.DocumentAttributeSticker,
  types.DocumentAttributeVideo,
  types.DocumentEmpty,
  types.DraftMessage,
  types.DraftMessageEmpty,
  types.EmailVerificationApple,
  types.EmailVerificationCode,
  types.EmailVerificationGoogle,
  types.EmailVerifyPurposeLoginChange,
  types.EmailVerifyPurposeLoginSetup,
  types.EmailVerifyPurposePassport,
  types.EmojiGroup,
  types.EmojiKeyword,
  types.EmojiKeywordDeleted,
  types.EmojiKeywordsDifference,
  types.EmojiLanguage,
  types.EmojiList,
  types.EmojiListNotModified,
  types.EmojiStatus,
  types.EmojiStatusEmpty,
  types.EmojiStatusUntil,
  types.EmojiUrl,
  types.EncryptedChat,
  types.EncryptedChatDiscarded,
  types.EncryptedChatEmpty,
  types.EncryptedChatRequested,
  types.EncryptedChatWaiting,
  types.EncryptedFile,
  types.EncryptedFileEmpty,
  types.EncryptedMessage,
  types.EncryptedMessageService,
  types.Error,
  types.ExportedChatlistInvite,
  types.ExportedContactToken,
  types.ExportedMessageLink,
  types.ExportedStoryLink,
  types.FileHash,
  types.Folder,
  types.FolderPeer,
  types.ForumTopic,
  types.ForumTopicDeleted,
  types.Game,
  types.GeoPoint,
  types.GeoPointEmpty,
  types.GlobalPrivacySettings,
  types.GroupCall,
  types.GroupCallDiscarded,
  types.GroupCallParticipant,
  types.GroupCallParticipantVideo,
  types.GroupCallParticipantVideoSourceGroup,
  types.GroupCallStreamChannel,
  types.HighScore,
  types.ImportedContact,
  types.InlineBotSwitchPm,
  types.InlineBotWebView,
  types.InlineQueryPeerTypeBotPm,
  types.InlineQueryPeerTypeBroadcast,
  types.InlineQueryPeerTypeChat,
  types.InlineQueryPeerTypeMegagroup,
  types.InlineQueryPeerTypePm,
  types.InlineQueryPeerTypeSameBotPm,
  types.InputAppEvent,
  types.InputBotAppId,
  types.InputBotAppShortName,
  types.InputBotInlineMessageGame,
  types.InputBotInlineMessageId,
  types.InputBotInlineMessageId64,
  types.InputBotInlineMessageMediaAuto,
  types.InputBotInlineMessageMediaContact,
  types.InputBotInlineMessageMediaGeo,
  types.InputBotInlineMessageMediaInvoice,
  types.InputBotInlineMessageMediaVenue,
  types.InputBotInlineMessageText,
  types.InputBotInlineResult,
  types.InputBotInlineResultDocument,
  types.InputBotInlineResultGame,
  types.InputBotInlineResultPhoto,
  types.InputChannel,
  types.InputChannelEmpty,
  types.InputChannelFromMessage,
  types.InputChatPhoto,
  types.InputChatPhotoEmpty,
  types.InputChatUploadedPhoto,
  types.InputChatlistDialogFilter,
  types.InputCheckPasswordEmpty,
  types.InputCheckPasswordSrp,
  types.InputClientProxy,
  types.InputDialogPeer,
  types.InputDialogPeerFolder,
  types.InputDocument,
  types.InputDocumentEmpty,
  types.InputDocumentFileLocation,
  types.InputEncryptedChat,
  types.InputEncryptedFile,
  types.InputEncryptedFileBigUploaded,
  types.InputEncryptedFileEmpty,
  types.InputEncryptedFileLocation,
  types.InputEncryptedFileUploaded,
  types.InputFile,
  types.InputFileBig,
  types.InputFileLocation,
  types.InputFolderPeer,
  types.InputGameId,
  types.InputGameShortName,
  types.InputGeoPoint,
  types.InputGeoPointEmpty,
  types.InputGroupCall,
  types.InputGroupCallStream,
  types.InputInvoiceMessage,
  types.InputInvoiceSlug,
  types.InputKeyboardButtonUrlAuth,
  types.InputKeyboardButtonUserProfile,
  types.InputMediaAreaVenue,
  types.InputMediaContact,
  types.InputMediaDice,
  types.InputMediaDocument,
  types.InputMediaDocumentExternal,
  types.InputMediaEmpty,
  types.InputMediaGame,
  types.InputMediaGeoLive,
  types.InputMediaGeoPoint,
  types.InputMediaInvoice,
  types.InputMediaPhoto,
  types.InputMediaPhotoExternal,
  types.InputMediaPoll,
  types.InputMediaStory,
  types.InputMediaUploadedDocument,
  types.InputMediaUploadedPhoto,
  types.InputMediaVenue,
  types.InputMessageCallbackQuery,
  types.InputMessageEntityMentionName,
  types.InputMessageId,
  types.InputMessagePinned,
  types.InputMessageReplyTo,
  types.InputMessagesFilterChatPhotos,
  types.InputMessagesFilterContacts,
  types.InputMessagesFilterDocument,
  types.InputMessagesFilterEmpty,
  types.InputMessagesFilterGeo,
  types.InputMessagesFilterGif,
  types.InputMessagesFilterMusic,
  types.InputMessagesFilterMyMentions,
  types.InputMessagesFilterPhoneCalls,
  types.InputMessagesFilterPhotoVideo,
  types.InputMessagesFilterPhotos,
  types.InputMessagesFilterPinned,
  types.InputMessagesFilterRoundVideo,
  types.InputMessagesFilterRoundVoice,
  types.InputMessagesFilterUrl,
  types.InputMessagesFilterVideo,
  types.InputMessagesFilterVoice,
  types.InputNotifyBroadcasts,
  types.InputNotifyChats,
  types.InputNotifyForumTopic,
  types.InputNotifyPeer,
  types.InputNotifyUsers,
  types.InputPaymentCredentials,
  types.InputPaymentCredentialsApplePay,
  types.InputPaymentCredentialsGooglePay,
  types.InputPaymentCredentialsSaved,
  types.InputPeerChannel,
  types.InputPeerChannelFromMessage,
  types.InputPeerChat,
  types.InputPeerEmpty,
  types.InputPeerNotifySettings,
  types.InputPeerPhotoFileLocation,
  types.InputPeerSelf,
  types.InputPeerUser,
  types.InputPeerUserFromMessage,
  types.InputPhoneCall,
  types.InputPhoneContact,
  types.InputPhoto,
  types.InputPhotoEmpty,
  types.InputPhotoFileLocation,
  types.InputPhotoLegacyFileLocation,
  types.InputPrivacyKeyAbout,
  types.InputPrivacyKeyAddedByPhone,
  types.InputPrivacyKeyChatInvite,
  types.InputPrivacyKeyForwards,
  types.InputPrivacyKeyPhoneCall,
  types.InputPrivacyKeyPhoneNumber,
  types.InputPrivacyKeyPhoneP2P,
  types.InputPrivacyKeyProfilePhoto,
  types.InputPrivacyKeyStatusTimestamp,
  types.InputPrivacyKeyVoiceMessages,
  types.InputPrivacyValueAllowAll,
  types.InputPrivacyValueAllowChatParticipants,
  types.InputPrivacyValueAllowCloseFriends,
  types.InputPrivacyValueAllowContacts,
  types.InputPrivacyValueAllowUsers,
  types.InputPrivacyValueDisallowAll,
  types.InputPrivacyValueDisallowChatParticipants,
  types.InputPrivacyValueDisallowContacts,
  types.InputPrivacyValueDisallowUsers,
  types.InputReplyToMessage,
  types.InputReplyToStory,
  types.InputReportReasonChildAbuse,
  types.InputReportReasonCopyright,
  types.InputReportReasonFake,
  types.InputReportReasonGeoIrrelevant,
  types.InputReportReasonIllegalDrugs,
  types.InputReportReasonOther,
  types.InputReportReasonPersonalDetails,
  types.InputReportReasonPornography,
  types.InputReportReasonSpam,
  types.InputReportReasonViolence,
  types.InputSecureFile,
  types.InputSecureFileLocation,
  types.InputSecureFileUploaded,
  types.InputSecureValue,
  types.InputSingleMedia,
  types.InputStickerSetAnimatedEmoji,
  types.InputStickerSetAnimatedEmojiAnimations,
  types.InputStickerSetDice,
  types.InputStickerSetEmojiDefaultStatuses,
  types.InputStickerSetEmojiDefaultTopicIcons,
  types.InputStickerSetEmojiGenericAnimations,
  types.InputStickerSetEmpty,
  types.InputStickerSetId,
  types.InputStickerSetItem,
  types.InputStickerSetPremiumGifts,
  types.InputStickerSetShortName,
  types.InputStickerSetThumb,
  types.InputStickeredMediaDocument,
  types.InputStickeredMediaPhoto,
  types.InputStorePaymentGiftPremium,
  types.InputStorePaymentPremiumSubscription,
  types.InputTakeoutFileLocation,
  types.InputTheme,
  types.InputThemeSettings,
  types.InputThemeSlug,
  types.InputUser,
  types.InputUserEmpty,
  types.InputUserFromMessage,
  types.InputUserSelf,
  types.InputWallPaper,
  types.InputWallPaperNoFile,
  types.InputWallPaperSlug,
  types.InputWebDocument,
  types.InputWebFileAudioAlbumThumbLocation,
  types.InputWebFileGeoPointLocation,
  types.InputWebFileLocation,
  types.Invoice,
  types.JsonArray,
  types.JsonBool,
  types.JsonNull,
  types.JsonNumber,
  types.JsonObject,
  types.JsonObjectValue,
  types.JsonString,
  types.KeyboardButton,
  types.KeyboardButtonBuy,
  types.KeyboardButtonCallback,
  types.KeyboardButtonGame,
  types.KeyboardButtonRequestGeoLocation,
  types.KeyboardButtonRequestPeer,
  types.KeyboardButtonRequestPhone,
  types.KeyboardButtonRequestPoll,
  types.KeyboardButtonRow,
  types.KeyboardButtonSimpleWebView,
  types.KeyboardButtonSwitchInline,
  types.KeyboardButtonUrl,
  types.KeyboardButtonUrlAuth,
  types.KeyboardButtonUserProfile,
  types.KeyboardButtonWebView,
  types.LabeledPrice,
  types.LangPackDifference,
  types.LangPackLanguage,
  types.LangPackString,
  types.LangPackStringDeleted,
  types.LangPackStringPluralized,
  types.MaskCoords,
  types.MediaAreaCoordinates,
  types.MediaAreaGeoPoint,
  types.MediaAreaSuggestedReaction,
  types.MediaAreaVenue,
  types.Message,
  types.MessageActionBotAllowed,
  types.MessageActionChannelCreate,
  types.MessageActionChannelMigrateFrom,
  types.MessageActionChatAddUser,
  types.MessageActionChatCreate,
  types.MessageActionChatDeletePhoto,
  types.MessageActionChatDeleteUser,
  types.MessageActionChatEditPhoto,
  types.MessageActionChatEditTitle,
  types.MessageActionChatJoinedByLink,
  types.MessageActionChatJoinedByRequest,
  types.MessageActionChatMigrateTo,
  types.MessageActionContactSignUp,
  types.MessageActionCustomAction,
  types.MessageActionEmpty,
  types.MessageActionGameScore,
  types.MessageActionGeoProximityReached,
  types.MessageActionGiftPremium,
  types.MessageActionGroupCall,
  types.MessageActionGroupCallScheduled,
  types.MessageActionHistoryClear,
  types.MessageActionInviteToGroupCall,
  types.MessageActionPaymentSent,
  types.MessageActionPaymentSentMe,
  types.MessageActionPhoneCall,
  types.MessageActionPinMessage,
  types.MessageActionRequestedPeer,
  types.MessageActionScreenshotTaken,
  types.MessageActionSecureValuesSent,
  types.MessageActionSecureValuesSentMe,
  types.MessageActionSetChatTheme,
  types.MessageActionSetChatWallPaper,
  types.MessageActionSetMessagesTtl,
  types.MessageActionSetSameChatWallPaper,
  types.MessageActionSuggestProfilePhoto,
  types.MessageActionTopicCreate,
  types.MessageActionTopicEdit,
  types.MessageActionWebViewDataSent,
  types.MessageActionWebViewDataSentMe,
  types.MessageEmpty,
  types.MessageEntityBankCard,
  types.MessageEntityBlockquote,
  types.MessageEntityBold,
  types.MessageEntityBotCommand,
  types.MessageEntityCashtag,
  types.MessageEntityCode,
  types.MessageEntityCustomEmoji,
  types.MessageEntityEmail,
  types.MessageEntityHashtag,
  types.MessageEntityItalic,
  types.MessageEntityMention,
  types.MessageEntityMentionName,
  types.MessageEntityPhone,
  types.MessageEntityPre,
  types.MessageEntitySpoiler,
  types.MessageEntityStrike,
  types.MessageEntityTextUrl,
  types.MessageEntityUnderline,
  types.MessageEntityUnknown,
  types.MessageEntityUrl,
  types.MessageExtendedMedia,
  types.MessageExtendedMediaPreview,
  types.MessageFwdHeader,
  types.MessageInteractionCounters,
  types.MessageMediaContact,
  types.MessageMediaDice,
  types.MessageMediaDocument,
  types.MessageMediaEmpty,
  types.MessageMediaGame,
  types.MessageMediaGeo,
  types.MessageMediaGeoLive,
  types.MessageMediaInvoice,
  types.MessageMediaPhoto,
  types.MessageMediaPoll,
  types.MessageMediaStory,
  types.MessageMediaUnsupported,
  types.MessageMediaVenue,
  types.MessageMediaWebPage,
  types.MessagePeerReaction,
  types.MessagePeerVote,
  types.MessagePeerVoteInputOption,
  types.MessagePeerVoteMultiple,
  types.MessageRange,
  types.MessageReactions,
  types.MessageReplies,
  types.MessageReplyHeader,
  types.MessageReplyStoryHeader,
  types.MessageService,
  types.MessageViews,
  types.NearestDc,
  types.NotificationSoundDefault,
  types.NotificationSoundLocal,
  types.NotificationSoundNone,
  types.NotificationSoundRingtone,
  types.NotifyBroadcasts,
  types.NotifyChats,
  types.NotifyForumTopic,
  types.NotifyPeer,
  types.NotifyUsers,
  types.Null,
  types.Page,
  types.PageBlockAnchor,
  types.PageBlockAudio,
  types.PageBlockAuthorDate,
  types.PageBlockBlockquote,
  types.PageBlockChannel,
  types.PageBlockCollage,
  types.PageBlockCover,
  types.PageBlockDetails,
  types.PageBlockDivider,
  types.PageBlockEmbed,
  types.PageBlockEmbedPost,
  types.PageBlockFooter,
  types.PageBlockHeader,
  types.PageBlockKicker,
  types.PageBlockList,
  types.PageBlockMap,
  types.PageBlockOrderedList,
  types.PageBlockParagraph,
  types.PageBlockPhoto,
  types.PageBlockPreformatted,
  types.PageBlockPullquote,
  types.PageBlockRelatedArticles,
  types.PageBlockSlideshow,
  types.PageBlockSubheader,
  types.PageBlockSubtitle,
  types.PageBlockTable,
  types.PageBlockTitle,
  types.PageBlockUnsupported,
  types.PageBlockVideo,
  types.PageCaption,
  types.PageListItemBlocks,
  types.PageListItemText,
  types.PageListOrderedItemBlocks,
  types.PageListOrderedItemText,
  types.PageRelatedArticle,
  types.PageTableCell,
  types.PageTableRow,
  types.PasswordKdfAlgoSha256Sha256Pbkdf2HmacshA512Iter100000Sha256ModPow,
  types.PasswordKdfAlgoUnknown,
  types.PaymentCharge,
  types.PaymentFormMethod,
  types.PaymentRequestedInfo,
  types.PaymentSavedCredentialsCard,
  types.PeerBlocked,
  types.PeerChannel,
  types.PeerChat,
  types.PeerLocated,
  types.PeerNotifySettings,
  types.PeerSelfLocated,
  types.PeerSettings,
  types.PeerStories,
  types.PeerUser,
  types.PhoneCall,
  types.PhoneCallAccepted,
  types.PhoneCallDiscardReasonBusy,
  types.PhoneCallDiscardReasonDisconnect,
  types.PhoneCallDiscardReasonHangup,
  types.PhoneCallDiscardReasonMissed,
  types.PhoneCallDiscarded,
  types.PhoneCallEmpty,
  types.PhoneCallProtocol,
  types.PhoneCallRequested,
  types.PhoneCallWaiting,
  types.PhoneConnection,
  types.PhoneConnectionWebrtc,
  types.Photo,
  types.PhotoCachedSize,
  types.PhotoEmpty,
  types.PhotoPathSize,
  types.PhotoSize,
  types.PhotoSizeEmpty,
  types.PhotoSizeProgressive,
  types.PhotoStrippedSize,
  types.Poll,
  types.PollAnswer,
  types.PollAnswerVoters,
  types.PollResults,
  types.PopularContact,
  types.PostAddress,
  types.PremiumGiftOption,
  types.PremiumSubscriptionOption,
  types.PrivacyKeyAbout,
  types.PrivacyKeyAddedByPhone,
  types.PrivacyKeyChatInvite,
  types.PrivacyKeyForwards,
  types.PrivacyKeyPhoneCall,
  types.PrivacyKeyPhoneNumber,
  types.PrivacyKeyPhoneP2P,
  types.PrivacyKeyProfilePhoto,
  types.PrivacyKeyStatusTimestamp,
  types.PrivacyKeyVoiceMessages,
  types.PrivacyValueAllowAll,
  types.PrivacyValueAllowChatParticipants,
  types.PrivacyValueAllowCloseFriends,
  types.PrivacyValueAllowContacts,
  types.PrivacyValueAllowUsers,
  types.PrivacyValueDisallowAll,
  types.PrivacyValueDisallowChatParticipants,
  types.PrivacyValueDisallowContacts,
  types.PrivacyValueDisallowUsers,
  types.ReactionCount,
  types.ReactionCustomEmoji,
  types.ReactionEmoji,
  types.ReactionEmpty,
  types.ReadParticipantDate,
  types.ReceivedNotifyMessage,
  types.RecentMeUrlChat,
  types.RecentMeUrlChatInvite,
  types.RecentMeUrlStickerSet,
  types.RecentMeUrlUnknown,
  types.RecentMeUrlUser,
  types.ReplyInlineMarkup,
  types.ReplyKeyboardForceReply,
  types.ReplyKeyboardHide,
  types.ReplyKeyboardMarkup,
  types.RequestPeerTypeBroadcast,
  types.RequestPeerTypeChat,
  types.RequestPeerTypeUser,
  types.RestrictionReason,
  types.SavedPhoneContact,
  types.SearchResultPosition,
  types.SearchResultsCalendarPeriod,
  types.SecureCredentialsEncrypted,
  types.SecureData,
  types.SecureFile,
  types.SecureFileEmpty,
  types.SecurePasswordKdfAlgoPbkdf2HmacshA512Iter100000,
  types.SecurePasswordKdfAlgoSha512,
  types.SecurePasswordKdfAlgoUnknown,
  types.SecurePlainEmail,
  types.SecurePlainPhone,
  types.SecureRequiredType,
  types.SecureRequiredTypeOneOf,
  types.SecureSecretSettings,
  types.SecureValue,
  types.SecureValueError,
  types.SecureValueErrorData,
  types.SecureValueErrorFile,
  types.SecureValueErrorFiles,
  types.SecureValueErrorFrontSide,
  types.SecureValueErrorReverseSide,
  types.SecureValueErrorSelfie,
  types.SecureValueErrorTranslationFile,
  types.SecureValueErrorTranslationFiles,
  types.SecureValueHash,
  types.SecureValueTypeAddress,
  types.SecureValueTypeBankStatement,
  types.SecureValueTypeDriverLicense,
  types.SecureValueTypeEmail,
  types.SecureValueTypeIdentityCard,
  types.SecureValueTypeInternalPassport,
  types.SecureValueTypePassport,
  types.SecureValueTypePassportRegistration,
  types.SecureValueTypePersonalDetails,
  types.SecureValueTypePhone,
  types.SecureValueTypeRentalAgreement,
  types.SecureValueTypeTemporaryRegistration,
  types.SecureValueTypeUtilityBill,
  types.SendAsPeer,
  types.SendMessageCancelAction,
  types.SendMessageChooseContactAction,
  types.SendMessageChooseStickerAction,
  types.SendMessageEmojiInteraction,
  types.SendMessageEmojiInteractionSeen,
  types.SendMessageGamePlayAction,
  types.SendMessageGeoLocationAction,
  types.SendMessageHistoryImportAction,
  types.SendMessageRecordAudioAction,
  types.SendMessageRecordRoundAction,
  types.SendMessageRecordVideoAction,
  types.SendMessageTypingAction,
  types.SendMessageUploadAudioAction,
  types.SendMessageUploadDocumentAction,
  types.SendMessageUploadPhotoAction,
  types.SendMessageUploadRoundAction,
  types.SendMessageUploadVideoAction,
  types.ShippingOption,
  types.SimpleWebViewResultUrl,
  types.SpeakingInGroupCallAction,
  types.SponsoredMessage,
  types.SponsoredWebPage,
  types.StatsAbsValueAndPrev,
  types.StatsDateRangeDays,
  types.StatsGraph,
  types.StatsGraphAsync,
  types.StatsGraphError,
  types.StatsGroupTopAdmin,
  types.StatsGroupTopInviter,
  types.StatsGroupTopPoster,
  types.StatsPercentValue,
  types.StatsUrl,
  types.StickerKeyword,
  types.StickerPack,
  types.StickerSet,
  types.StickerSetCovered,
  types.StickerSetFullCovered,
  types.StickerSetMultiCovered,
  types.StickerSetNoCovered,
  types.StoriesStealthMode,
  types.StoryItem,
  types.StoryItemDeleted,
  types.StoryItemSkipped,
  types.StoryView,
  types.StoryViews,
  types.TextAnchor,
  types.TextBold,
  types.TextConcat,
  types.TextEmail,
  types.TextEmpty,
  types.TextFixed,
  types.TextImage,
  types.TextItalic,
  types.TextMarked,
  types.TextPhone,
  types.TextPlain,
  types.TextStrike,
  types.TextSubscript,
  types.TextSuperscript,
  types.TextUnderline,
  types.TextUrl,
  types.TextWithEntities,
  types.Theme,
  types.ThemeSettings,
  types.TopPeer,
  types.TopPeerCategoryBotsInline,
  types.TopPeerCategoryBotsPm,
  types.TopPeerCategoryChannels,
  types.TopPeerCategoryCorrespondents,
  types.TopPeerCategoryForwardChats,
  types.TopPeerCategoryForwardUsers,
  types.TopPeerCategoryGroups,
  types.TopPeerCategoryPeers,
  types.TopPeerCategoryPhoneCalls,
  types.UpdateAttachMenuBots,
  types.UpdateAutoSaveSettings,
  types.UpdateBotCallbackQuery,
  types.UpdateBotChatInviteRequester,
  types.UpdateBotCommands,
  types.UpdateBotInlineQuery,
  types.UpdateBotInlineSend,
  types.UpdateBotMenuButton,
  types.UpdateBotPrecheckoutQuery,
  types.UpdateBotShippingQuery,
  types.UpdateBotStopped,
  types.UpdateBotWebhookJson,
  types.UpdateBotWebhookJsonQuery,
  types.UpdateChannel,
  types.UpdateChannelAvailableMessages,
  types.UpdateChannelMessageForwards,
  types.UpdateChannelMessageViews,
  types.UpdateChannelParticipant,
  types.UpdateChannelPinnedTopic,
  types.UpdateChannelPinnedTopics,
  types.UpdateChannelReadMessagesContents,
  types.UpdateChannelTooLong,
  types.UpdateChannelUserTyping,
  types.UpdateChannelWebPage,
  types.UpdateChat,
  types.UpdateChatDefaultBannedRights,
  types.UpdateChatParticipant,
  types.UpdateChatParticipantAdd,
  types.UpdateChatParticipantAdmin,
  types.UpdateChatParticipantDelete,
  types.UpdateChatParticipants,
  types.UpdateChatUserTyping,
  types.UpdateConfig,
  types.UpdateContactsReset,
  types.UpdateDcOptions,
  types.UpdateDeleteChannelMessages,
  types.UpdateDeleteMessages,
  types.UpdateDeleteScheduledMessages,
  types.UpdateDialogFilter,
  types.UpdateDialogFilterOrder,
  types.UpdateDialogFilters,
  types.UpdateDialogPinned,
  types.UpdateDialogUnreadMark,
  types.UpdateDraftMessage,
  types.UpdateEditChannelMessage,
  types.UpdateEditMessage,
  types.UpdateEncryptedChatTyping,
  types.UpdateEncryptedMessagesRead,
  types.UpdateEncryption,
  types.UpdateFavedStickers,
  types.UpdateFolderPeers,
  types.UpdateGeoLiveViewed,
  types.UpdateGroupCall,
  types.UpdateGroupCallConnection,
  types.UpdateGroupCallParticipants,
  types.UpdateGroupInvitePrivacyForbidden,
  types.UpdateInlineBotCallbackQuery,
  types.UpdateLangPack,
  types.UpdateLangPackTooLong,
  types.UpdateLoginToken,
  types.UpdateMessageExtendedMedia,
  types.UpdateMessageId,
  types.UpdateMessagePoll,
  types.UpdateMessagePollVote,
  types.UpdateMessageReactions,
  types.UpdateMoveStickerSetToTop,
  types.UpdateNewAuthorization,
  types.UpdateNewChannelMessage,
  types.UpdateNewEncryptedMessage,
  types.UpdateNewMessage,
  types.UpdateNewScheduledMessage,
  types.UpdateNewStickerSet,
  types.UpdateNotifySettings,
  types.UpdatePeerBlocked,
  types.UpdatePeerHistoryTtl,
  types.UpdatePeerLocated,
  types.UpdatePeerSettings,
  types.UpdatePendingJoinRequests,
  types.UpdatePhoneCall,
  types.UpdatePhoneCallSignalingData,
  types.UpdatePinnedChannelMessages,
  types.UpdatePinnedDialogs,
  types.UpdatePinnedMessages,
  types.UpdatePrivacy,
  types.UpdatePtsChanged,
  types.UpdateReadChannelDiscussionInbox,
  types.UpdateReadChannelDiscussionOutbox,
  types.UpdateReadChannelInbox,
  types.UpdateReadChannelOutbox,
  types.UpdateReadFeaturedEmojiStickers,
  types.UpdateReadFeaturedStickers,
  types.UpdateReadHistoryInbox,
  types.UpdateReadHistoryOutbox,
  types.UpdateReadMessagesContents,
  types.UpdateReadStories,
  types.UpdateRecentEmojiStatuses,
  types.UpdateRecentReactions,
  types.UpdateRecentStickers,
  types.UpdateSavedGifs,
  types.UpdateSavedRingtones,
  types.UpdateSentStoryReaction,
  types.UpdateServiceNotification,
  types.UpdateShort,
  types.UpdateShortChatMessage,
  types.UpdateShortMessage,
  types.UpdateShortSentMessage,
  types.UpdateStickerSets,
  types.UpdateStickerSetsOrder,
  types.UpdateStoriesStealthMode,
  types.UpdateStory,
  types.UpdateStoryId,
  types.UpdateTheme,
  types.UpdateTranscribedAudio,
  types.UpdateUser,
  types.UpdateUserEmojiStatus,
  types.UpdateUserName,
  types.UpdateUserPhone,
  types.UpdateUserStatus,
  types.UpdateUserTyping,
  types.UpdateWebPage,
  types.UpdateWebViewResultSent,
  types.Updates,
  types.UpdatesCombined,
  types.UpdatesTooLong,
  types.UrlAuthResultAccepted,
  types.UrlAuthResultDefault,
  types.UrlAuthResultRequest,
  types.User,
  types.UserEmpty,
  types.UserFull,
  types.UserProfilePhoto,
  types.UserProfilePhotoEmpty,
  types.UserStatusEmpty,
  types.UserStatusLastMonth,
  types.UserStatusLastWeek,
  types.UserStatusOffline,
  types.UserStatusOnline,
  types.UserStatusRecently,
  types.Username,
  types.VideoSize,
  types.VideoSizeEmojiMarkup,
  types.VideoSizeStickerMarkup,
  types.WallPaper,
  types.WallPaperNoFile,
  types.WallPaperSettings,
  types.WebAuthorization,
  types.WebDocument,
  types.WebDocumentNoProxy,
  types.WebPage,
  types.WebPageAttributeStory,
  types.WebPageAttributeTheme,
  types.WebPageEmpty,
  types.WebPageNotModified,
  types.WebPagePending,
  types.WebViewMessageSent,
  types.WebViewResultUrl,
  types.account.AuthorizationForm,
  types.account.Authorizations,
  types.account.AutoDownloadSettings,
  types.account.AutoSaveSettings,
  types.account.ContentSettings,
  types.account.EmailVerified,
  types.account.EmailVerifiedLogin,
  types.account.EmojiStatuses,
  types.account.EmojiStatusesNotModified,
  types.account.Password,
  types.account.PasswordInputSettings,
  types.account.PasswordSettings,
  types.account.PrivacyRules,
  types.account.ResetPasswordFailedWait,
  types.account.ResetPasswordOk,
  types.account.ResetPasswordRequestedWait,
  types.account.SavedRingtone,
  types.account.SavedRingtoneConverted,
  types.account.SavedRingtones,
  types.account.SavedRingtonesNotModified,
  types.account.SentEmailCode,
  types.account.Takeout,
  types.account.Themes,
  types.account.ThemesNotModified,
  types.account.TmpPassword,
  types.account.WallPapers,
  types.account.WallPapersNotModified,
  types.account.WebAuthorizations,
  types.auth.Authorization,
  types.auth.AuthorizationSignUpRequired,
  types.auth.CodeTypeCall,
  types.auth.CodeTypeFlashCall,
  types.auth.CodeTypeFragmentSms,
  types.auth.CodeTypeMissedCall,
  types.auth.CodeTypeSms,
  types.auth.ExportedAuthorization,
  types.auth.LoggedOut,
  types.auth.LoginToken,
  types.auth.LoginTokenMigrateTo,
  types.auth.LoginTokenSuccess,
  types.auth.PasswordRecovery,
  types.auth.SentCode,
  types.auth.SentCodeSuccess,
  types.auth.SentCodeTypeApp,
  types.auth.SentCodeTypeCall,
  types.auth.SentCodeTypeEmailCode,
  types.auth.SentCodeTypeFirebaseSms,
  types.auth.SentCodeTypeFlashCall,
  types.auth.SentCodeTypeFragmentSms,
  types.auth.SentCodeTypeMissedCall,
  types.auth.SentCodeTypeSetUpEmailRequired,
  types.auth.SentCodeTypeSms,
  types.bots.BotInfo,
  types.channels.AdminLogResults,
  types.channels.ChannelParticipant,
  types.channels.ChannelParticipants,
  types.channels.ChannelParticipantsNotModified,
  types.channels.SendAsPeers,
  types.chatlists.ChatlistInvite,
  types.chatlists.ChatlistInviteAlready,
  types.chatlists.ChatlistUpdates,
  types.chatlists.ExportedChatlistInvite,
  types.chatlists.ExportedInvites,
  types.contacts.Blocked,
  types.contacts.BlockedSlice,
  types.contacts.Contacts,
  types.contacts.ContactsNotModified,
  types.contacts.Found,
  types.contacts.ImportedContacts,
  types.contacts.ResolvedPeer,
  types.contacts.TopPeers,
  types.contacts.TopPeersDisabled,
  types.contacts.TopPeersNotModified,
  types.help.AppConfig,
  types.help.AppConfigNotModified,
  types.help.AppUpdate,
  types.help.CountriesList,
  types.help.CountriesListNotModified,
  types.help.Country,
  types.help.CountryCode,
  types.help.DeepLinkInfo,
  types.help.DeepLinkInfoEmpty,
  types.help.InviteText,
  types.help.NoAppUpdate,
  types.help.PassportConfig,
  types.help.PassportConfigNotModified,
  types.help.PremiumPromo,
  types.help.PromoData,
  types.help.PromoDataEmpty,
  types.help.RecentMeUrls,
  types.help.Support,
  types.help.SupportName,
  types.help.TermsOfService,
  types.help.TermsOfServiceUpdate,
  types.help.TermsOfServiceUpdateEmpty,
  types.help.UserInfo,
  types.help.UserInfoEmpty,
  types.messages.AffectedFoundMessages,
  types.messages.AffectedHistory,
  types.messages.AffectedMessages,
  types.messages.AllStickers,
  types.messages.AllStickersNotModified,
  types.messages.ArchivedStickers,
  types.messages.AvailableReactions,
  types.messages.AvailableReactionsNotModified,
  types.messages.BotApp,
  types.messages.BotCallbackAnswer,
  types.messages.BotResults,
  types.messages.ChannelMessages,
  types.messages.ChatAdminsWithInvites,
  types.messages.ChatFull,
  types.messages.ChatInviteImporters,
  types.messages.Chats,
  types.messages.ChatsSlice,
  types.messages.CheckedHistoryImportPeer,
  types.messages.DhConfig,
  types.messages.DhConfigNotModified,
  types.messages.Dialogs,
  types.messages.DialogsNotModified,
  types.messages.DialogsSlice,
  types.messages.DiscussionMessage,
  types.messages.EmojiGroups,
  types.messages.EmojiGroupsNotModified,
  types.messages.ExportedChatInvite,
  types.messages.ExportedChatInviteReplaced,
  types.messages.ExportedChatInvites,
  types.messages.FavedStickers,
  types.messages.FavedStickersNotModified,
  types.messages.FeaturedStickers,
  types.messages.FeaturedStickersNotModified,
  types.messages.ForumTopics,
  types.messages.FoundStickerSets,
  types.messages.FoundStickerSetsNotModified,
  types.messages.HighScores,
  types.messages.HistoryImport,
  types.messages.HistoryImportParsed,
  types.messages.InactiveChats,
  types.messages.MessageEditData,
  types.messages.MessageReactionsList,
  types.messages.MessageViews,
  types.messages.Messages,
  types.messages.MessagesNotModified,
  types.messages.MessagesSlice,
  types.messages.PeerDialogs,
  types.messages.PeerSettings,
  types.messages.Reactions,
  types.messages.ReactionsNotModified,
  types.messages.RecentStickers,
  types.messages.RecentStickersNotModified,
  types.messages.SavedGifs,
  types.messages.SavedGifsNotModified,
  types.messages.SearchCounter,
  types.messages.SearchResultsCalendar,
  types.messages.SearchResultsPositions,
  types.messages.SentEncryptedFile,
  types.messages.SentEncryptedMessage,
  types.messages.SponsoredMessages,
  types.messages.SponsoredMessagesEmpty,
  types.messages.StickerSet,
  types.messages.StickerSetInstallResultArchive,
  types.messages.StickerSetInstallResultSuccess,
  types.messages.StickerSetNotModified,
  types.messages.Stickers,
  types.messages.StickersNotModified,
  types.messages.TranscribedAudio,
  types.messages.TranslateResult,
  types.messages.VotesList,
  types.messages.WebPage,
  types.payments.BankCardData,
  types.payments.ExportedInvoice,
  types.payments.PaymentForm,
  types.payments.PaymentReceipt,
  types.payments.PaymentResult,
  types.payments.PaymentVerificationNeeded,
  types.payments.SavedInfo,
  types.payments.ValidatedRequestedInfo,
  types.phone.ExportedGroupCallInvite,
  types.phone.GroupCall,
  types.phone.GroupCallStreamChannels,
  types.phone.GroupCallStreamRtmpUrl,
  types.phone.GroupParticipants,
  types.phone.JoinAsPeers,
  types.phone.PhoneCall,
  types.photos.Photo,
  types.photos.Photos,
  types.photos.PhotosSlice,
  types.stats.BroadcastStats,
  types.stats.MegagroupStats,
  types.stats.MessageStats,
  types.stickers.SuggestedShortName,
  types.storage.FileGif,
  types.storage.FileJpeg,
  types.storage.FileMov,
  types.storage.FileMp3,
  types.storage.FileMp4,
  types.storage.FilePartial,
  types.storage.FilePdf,
  types.storage.FilePng,
  types.storage.FileUnknown,
  types.storage.FileWebp,
  types.stories.AllStories,
  types.stories.AllStoriesNotModified,
  types.stories.BoostersList,
  types.stories.BoostsStatus,
  types.stories.CanApplyBoostOk,
  types.stories.CanApplyBoostReplace,
  types.stories.PeerStories,
  types.stories.Stories,
  types.stories.StoryViews,
  types.stories.StoryViewsList,
  types.updates.ChannelDifference,
  types.updates.ChannelDifferenceEmpty,
  types.updates.ChannelDifferenceTooLong,
  types.updates.Difference,
  types.updates.DifferenceEmpty,
  types.updates.DifferenceSlice,
  types.updates.DifferenceTooLong,
  types.updates.State,
  types.upload.CdnFile,
  types.upload.CdnFileReuploadNeeded,
  types.upload.File,
  types.upload.FileCdnRedirect,
  types.upload.WebFile,
  types.users.UserFull,
))}
RESPONSE_MAPPING = {
  0xcb9f372d: deserialize_identity,
  0x3dc4b4f0: deserialize_identity,
  0xc1cd5ea9: deserialize_identity,
  0xda9b0d0d: deserialize_identity,
  0xbf9459b7: deserialize_identity,
  0x365275f2: deserialize_identity,
  0xaca9fd2e: deserialize_identity,
  0xa677244f: single_deserializer(abcs.auth.SentCode),
  0x80eee427: single_deserializer(abcs.auth.Authorization),
  0x8d52a951: single_deserializer(abcs.auth.Authorization),
  0x3e72ba19: single_deserializer(abcs.auth.LoggedOut),
  0x9fab0d1a: deserialize_bool,
  0xe5bfffcd: single_deserializer(abcs.auth.ExportedAuthorization),
  0xa57a7dad: single_deserializer(abcs.auth.Authorization),
  0xcdd42a05: deserialize_bool,
  0x67a3ff2c: single_deserializer(abcs.auth.Authorization),
  0xd18b4d16: single_deserializer(abcs.auth.Authorization),
  0xd897bc66: single_deserializer(abcs.auth.PasswordRecovery),
  0x37096c70: single_deserializer(abcs.auth.Authorization),
  0x3ef1a9bf: single_deserializer(abcs.auth.SentCode),
  0x1f040578: deserialize_bool,
  0x8e48a188: deserialize_bool,
  0xb7e085fe: single_deserializer(abcs.auth.LoginToken),
  0x95ac5ce4: single_deserializer(abcs.auth.LoginToken),
  0xe894ad4d: single_deserializer(abcs.Authorization),
  0xd36bf79: deserialize_bool,
  0x2db873a9: single_deserializer(abcs.auth.Authorization),
  0x89464b50: deserialize_bool,
  0x7e960193: single_deserializer(abcs.auth.SentCode),
  0xec86017a: deserialize_bool,
  0x6a0d3206: deserialize_bool,
  0x84be5b93: deserialize_bool,
  0x12b3ad31: single_deserializer(abcs.PeerNotifySettings),
  0xdb7e1747: deserialize_bool,
  0x78515775: single_deserializer(abcs.User),
  0x6628562c: deserialize_bool,
  0x7967d36: single_deserializer(abcs.account.WallPapers),
  0xc5ba3d86: deserialize_bool,
  0x2714d86c: deserialize_bool,
  0x3e0bdd7c: single_deserializer(abcs.User),
  0xdadbc950: single_deserializer(abcs.account.PrivacyRules),
  0xc9f81ce8: single_deserializer(abcs.account.PrivacyRules),
  0xa2c0cf74: deserialize_bool,
  0x8fc711d: single_deserializer(abcs.AccountDaysTtl),
  0x2442485e: deserialize_bool,
  0x82574ae5: single_deserializer(abcs.auth.SentCode),
  0x70c32edb: single_deserializer(abcs.User),
  0x38df3532: deserialize_bool,
  0xe320c158: single_deserializer(abcs.account.Authorizations),
  0xdf77f3bc: deserialize_bool,
  0x548a30f5: single_deserializer(abcs.account.Password),
  0x9cd4eaf9: single_deserializer(abcs.account.PasswordSettings),
  0xa59b102f: deserialize_bool,
  0x1b3faa88: single_deserializer(abcs.auth.SentCode),
  0x5f2178c3: deserialize_bool,
  0x449e0b51: single_deserializer(abcs.account.TmpPassword),
  0x182e6d6f: single_deserializer(abcs.account.WebAuthorizations),
  0x2d01b9ef: deserialize_bool,
  0x682d2594: deserialize_bool,
  0xb288bc7d: list_deserializer(abcs.SecureValue),
  0x73665bc2: list_deserializer(abcs.SecureValue),
  0x899fe31d: single_deserializer(abcs.SecureValue),
  0xb880bc4b: deserialize_bool,
  0xa929597a: single_deserializer(abcs.account.AuthorizationForm),
  0xf3ed4c73: deserialize_bool,
  0xa5a356f9: single_deserializer(abcs.auth.SentCode),
  0x4dd3a7f6: deserialize_bool,
  0x98e037bb: single_deserializer(abcs.account.SentEmailCode),
  0x32da4cf: single_deserializer(abcs.account.EmailVerified),
  0x8ef3eab0: single_deserializer(abcs.account.Takeout),
  0x1d2652ee: deserialize_bool,
  0x8fdf1920: deserialize_bool,
  0x7a7f2a15: deserialize_bool,
  0xc1cbd5b6: deserialize_bool,
  0x9f07c728: deserialize_bool,
  0xcff43f61: deserialize_bool,
  0x53577479: single_deserializer(abcs.Updates),
  0xfc8ddbea: single_deserializer(abcs.WallPaper),
  0xe39a8f03: single_deserializer(abcs.WallPaper),
  0x6c5a5b37: deserialize_bool,
  0xfeed5769: deserialize_bool,
  0xbb3b9804: deserialize_bool,
  0x56da0b3f: single_deserializer(abcs.account.AutoDownloadSettings),
  0x76f36233: deserialize_bool,
  0x1c3db333: single_deserializer(abcs.Document),
  0x652e4400: single_deserializer(abcs.Theme),
  0x2bf40ccc: single_deserializer(abcs.Theme),
  0xf257106c: deserialize_bool,
  0xc727bb3b: deserialize_bool,
  0x3a5869ec: single_deserializer(abcs.Theme),
  0x7206e458: single_deserializer(abcs.account.Themes),
  0xb574b16b: deserialize_bool,
  0x8b9b4dae: single_deserializer(abcs.account.ContentSettings),
  0x65ad71dc: list_deserializer(abcs.WallPaper),
  0xeb2b4cf6: single_deserializer(abcs.GlobalPrivacySettings),
  0x1edaaac2: single_deserializer(abcs.GlobalPrivacySettings),
  0xfa8cc6f5: deserialize_bool,
  0x9308ce1b: single_deserializer(abcs.account.ResetPasswordResult),
  0x4c9409f6: deserialize_bool,
  0xd638de89: single_deserializer(abcs.account.Themes),
  0xbf899aa0: deserialize_bool,
  0x40f48462: deserialize_bool,
  0xe1902288: single_deserializer(abcs.account.SavedRingtones),
  0x3dea5b03: single_deserializer(abcs.account.SavedRingtone),
  0x831a83a2: single_deserializer(abcs.Document),
  0xfbd3de6b: deserialize_bool,
  0xd6753386: single_deserializer(abcs.account.EmojiStatuses),
  0xf578105: single_deserializer(abcs.account.EmojiStatuses),
  0x18201aae: deserialize_bool,
  0xef500eab: deserialize_bool,
  0x58d6b376: deserialize_bool,
  0xe2750328: single_deserializer(abcs.EmojiList),
  0x915860ae: single_deserializer(abcs.EmojiList),
  0xadcbbcda: single_deserializer(abcs.account.AutoSaveSettings),
  0xd69b8361: deserialize_bool,
  0x53bc0020: deserialize_bool,
  0xca8ae8ba: deserialize_bool,
  0xd91a548: list_deserializer(abcs.User),
  0xb60f5918: single_deserializer(abcs.users.UserFull),
  0x90c894b5: deserialize_bool,
  0x7adc669d: deserialize_i32_list,
  0xc4a353ee: list_deserializer(abcs.ContactStatus),
  0x5dd69e12: single_deserializer(abcs.contacts.Contacts),
  0x2c800be5: single_deserializer(abcs.contacts.ImportedContacts),
  0x96a0e00: single_deserializer(abcs.Updates),
  0x1013fd9e: deserialize_bool,
  0x2e2e8734: deserialize_bool,
  0xb550d328: deserialize_bool,
  0x9a868f80: single_deserializer(abcs.contacts.Blocked),
  0x11f812d8: single_deserializer(abcs.contacts.Found),
  0xf93ccba3: single_deserializer(abcs.contacts.ResolvedPeer),
  0x973478b6: single_deserializer(abcs.contacts.TopPeers),
  0x1ae373ac: deserialize_bool,
  0x879537f1: deserialize_bool,
  0x82f1e39f: list_deserializer(abcs.SavedContact),
  0x8514bdda: deserialize_bool,
  0xe8f463d0: single_deserializer(abcs.Updates),
  0xf831a20f: single_deserializer(abcs.Updates),
  0xd348bc44: single_deserializer(abcs.Updates),
  0x29a8962c: single_deserializer(abcs.Updates),
  0x8af94344: single_deserializer(abcs.contacts.ResolvedPeer),
  0xf8654027: single_deserializer(abcs.ExportedContactToken),
  0x13005788: single_deserializer(abcs.User),
  0xba6705f0: deserialize_bool,
  0x94c65c76: deserialize_bool,
  0x63c66506: single_deserializer(abcs.messages.Messages),
  0xa0f4cb4f: single_deserializer(abcs.messages.Dialogs),
  0x4423e6c5: single_deserializer(abcs.messages.Messages),
  0xa0fda762: single_deserializer(abcs.messages.Messages),
  0xe306d3a: single_deserializer(abcs.messages.AffectedMessages),
  0xb08f922a: single_deserializer(abcs.messages.AffectedHistory),
  0xe58e95d2: single_deserializer(abcs.messages.AffectedMessages),
  0x5a954c0: list_deserializer(abcs.ReceivedNotifyMessage),
  0x58943ee2: deserialize_bool,
  0x280d096f: single_deserializer(abcs.Updates),
  0x72ccc23d: single_deserializer(abcs.Updates),
  0xc661bbc4: single_deserializer(abcs.Updates),
  0xcf1592db: deserialize_bool,
  0xefd9a6a2: single_deserializer(abcs.messages.PeerSettings),
  0x8953ab4e: deserialize_bool,
  0x49e9528f: single_deserializer(abcs.messages.Chats),
  0xaeb00b34: single_deserializer(abcs.messages.ChatFull),
  0x73783ffd: single_deserializer(abcs.Updates),
  0x35ddd674: single_deserializer(abcs.Updates),
  0xf24753e3: single_deserializer(abcs.Updates),
  0xa2185cab: single_deserializer(abcs.Updates),
  0x34a818: single_deserializer(abcs.Updates),
  0x26cf8950: single_deserializer(abcs.messages.DhConfig),
  0xf64daf43: single_deserializer(abcs.EncryptedChat),
  0x3dbc0415: single_deserializer(abcs.EncryptedChat),
  0xf393aea0: deserialize_bool,
  0x791451ed: deserialize_bool,
  0x7f4b690a: deserialize_bool,
  0x44fa7a15: single_deserializer(abcs.messages.SentEncryptedMessage),
  0x5559481d: single_deserializer(abcs.messages.SentEncryptedMessage),
  0x32d439a4: single_deserializer(abcs.messages.SentEncryptedMessage),
  0x55a5bb66: deserialize_i64_list,
  0x4b0c8c0f: deserialize_bool,
  0x36a73f77: single_deserializer(abcs.messages.AffectedMessages),
  0xd5a5d3a1: single_deserializer(abcs.messages.Stickers),
  0xb8a0a1a8: single_deserializer(abcs.messages.AllStickers),
  0x8b68b0cc: single_deserializer(abcs.MessageMedia),
  0xa02ce5d5: single_deserializer(abcs.ExportedChatInvite),
  0x3eadb1bb: single_deserializer(abcs.ChatInvite),
  0x6c50051c: single_deserializer(abcs.Updates),
  0xc8a0ec74: single_deserializer(abcs.messages.StickerSet),
  0xc78fe460: single_deserializer(abcs.messages.StickerSetInstallResult),
  0xf96e55de: deserialize_bool,
  0xe6df7378: single_deserializer(abcs.Updates),
  0x5784d3e1: single_deserializer(abcs.messages.MessageViews),
  0xa85bd1c2: deserialize_bool,
  0xa2875319: single_deserializer(abcs.Updates),
  0x4bc6589a: single_deserializer(abcs.messages.Messages),
  0x78337739: deserialize_bool,
  0xb1f2061f: single_deserializer(abcs.Document),
  0x5cf09635: single_deserializer(abcs.messages.SavedGifs),
  0x327a30cb: deserialize_bool,
  0x514e999d: single_deserializer(abcs.messages.BotResults),
  0xbb12a419: deserialize_bool,
  0xf7bc68ba: single_deserializer(abcs.Updates),
  0xfda68d36: single_deserializer(abcs.messages.MessageEditData),
  0x48f71778: single_deserializer(abcs.Updates),
  0x83557dba: deserialize_bool,
  0x9342ca07: single_deserializer(abcs.messages.BotCallbackAnswer),
  0xd58f130a: deserialize_bool,
  0xe470bcfd: single_deserializer(abcs.messages.PeerDialogs),
  0xb4331e3f: deserialize_bool,
  0x6a3f8d65: single_deserializer(abcs.Updates),
  0x64780b14: single_deserializer(abcs.messages.FeaturedStickers),
  0x5b118126: deserialize_bool,
  0x9da9403b: single_deserializer(abcs.messages.RecentStickers),
  0x392718f8: deserialize_bool,
  0x8999602d: deserialize_bool,
  0x57f17692: single_deserializer(abcs.messages.ArchivedStickers),
  0x640f82b8: single_deserializer(abcs.messages.AllStickers),
  0xcc5b67cc: list_deserializer(abcs.StickerSetCovered),
  0x8ef8ecc0: single_deserializer(abcs.Updates),
  0x15ad9f64: deserialize_bool,
  0xe822649d: single_deserializer(abcs.messages.HighScores),
  0xf635e1b: single_deserializer(abcs.messages.HighScores),
  0xe40ca104: single_deserializer(abcs.messages.Chats),
  0x8d9692a3: single_deserializer(abcs.messages.WebPage),
  0xa731e257: deserialize_bool,
  0x3b1adf37: deserialize_bool,
  0xd6b94df2: single_deserializer(abcs.messages.PeerDialogs),
  0xe5f672fa: deserialize_bool,
  0x9c2dd95: deserialize_bool,
  0x519bc2b1: single_deserializer(abcs.MessageMedia),
  0xa1405817: single_deserializer(abcs.Updates),
  0x4f1aaa9: single_deserializer(abcs.messages.FavedStickers),
  0xb9ffc55b: deserialize_bool,
  0xf107e790: single_deserializer(abcs.messages.Messages),
  0x36e5bf4d: single_deserializer(abcs.messages.AffectedHistory),
  0x702a40e0: single_deserializer(abcs.messages.Messages),
  0x456e8987: single_deserializer(abcs.Updates),
  0x5057c497: single_deserializer(abcs.EncryptedFile),
  0x35705b8a: single_deserializer(abcs.messages.FoundStickerSets),
  0x1cff7e08: list_deserializer(abcs.MessageRange),
  0xc286d98f: deserialize_bool,
  0x22e24e22: list_deserializer(abcs.DialogPeer),
  0x7e58ee9c: deserialize_bool,
  0xd2aaf7ec: single_deserializer(abcs.Updates),
  0x10ea6184: single_deserializer(abcs.Updates),
  0x73bb643b: single_deserializer(abcs.Updates),
  0x6e2be050: single_deserializer(abcs.ChatOnlines),
  0xdef60797: deserialize_bool,
  0xa5866b41: single_deserializer(abcs.Updates),
  0x35a0e062: single_deserializer(abcs.EmojiKeywordsDifference),
  0x1508b6af: single_deserializer(abcs.EmojiKeywordsDifference),
  0x4e9963b2: list_deserializer(abcs.EmojiLanguage),
  0xd5b10c26: single_deserializer(abcs.EmojiUrl),
  0xae7cc1: list_deserializer(abcs.messages.SearchCounter),
  0x198fb446: single_deserializer(abcs.UrlAuthResult),
  0xb12c7125: single_deserializer(abcs.UrlAuthResult),
  0x4facb138: deserialize_bool,
  0xf516760b: single_deserializer(abcs.messages.Messages),
  0xbdbb0464: single_deserializer(abcs.messages.Messages),
  0xbd38850a: single_deserializer(abcs.Updates),
  0x59ae2b16: single_deserializer(abcs.Updates),
  0xb86e380e: single_deserializer(abcs.messages.VotesList),
  0xb5052fea: deserialize_bool,
  0xf19ed96d: list_deserializer(abcs.DialogFilter),
  0xa29cd42c: list_deserializer(abcs.DialogFilterSuggested),
  0x1ad4a04a: deserialize_bool,
  0xc563c1e4: deserialize_bool,
  0x7ed094a1: single_deserializer(abcs.messages.FeaturedStickers),
  0x22ddd30c: single_deserializer(abcs.messages.Messages),
  0x446972fd: single_deserializer(abcs.messages.DiscussionMessage),
  0xf731a9f4: deserialize_bool,
  0xee22b9a8: single_deserializer(abcs.messages.AffectedHistory),
  0x5bd0ee50: deserialize_bool,
  0xf9cbe409: single_deserializer(abcs.messages.AffectedFoundMessages),
  0x43fe19f3: single_deserializer(abcs.messages.HistoryImportParsed),
  0x34090c3b: single_deserializer(abcs.messages.HistoryImport),
  0x2a862092: single_deserializer(abcs.MessageMedia),
  0xb43df344: deserialize_bool,
  0xa2b5a3f6: single_deserializer(abcs.messages.ExportedChatInvites),
  0x73746f5c: single_deserializer(abcs.messages.ExportedChatInvite),
  0xbdca2f75: single_deserializer(abcs.messages.ExportedChatInvite),
  0x56987bd5: deserialize_bool,
  0xd464a42b: deserialize_bool,
  0x3920e6ef: single_deserializer(abcs.messages.ChatAdminsWithInvites),
  0xdf04dd4e: single_deserializer(abcs.messages.ChatInviteImporters),
  0xb80e5fe4: single_deserializer(abcs.Updates),
  0x5dc60f03: single_deserializer(abcs.messages.CheckedHistoryImportPeer),
  0xe63be13f: single_deserializer(abcs.Updates),
  0x31c1c44f: list_deserializer(abcs.ReadParticipantDate),
  0x49f0bde9: single_deserializer(abcs.messages.SearchResultsCalendar),
  0x6e9583a3: single_deserializer(abcs.messages.SearchResultsPositions),
  0x7fe7e815: single_deserializer(abcs.Updates),
  0xe085f4ea: single_deserializer(abcs.Updates),
  0xb11eafa2: single_deserializer(abcs.Updates),
  0xccfddf96: deserialize_bool,
  0xd30d78d4: single_deserializer(abcs.Updates),
  0x8bba90e6: single_deserializer(abcs.Updates),
  0x461b3f48: single_deserializer(abcs.messages.MessageReactionsList),
  0xfeb16771: single_deserializer(abcs.Updates),
  0x18dea0ac: single_deserializer(abcs.messages.AvailableReactions),
  0x4f47a016: deserialize_bool,
  0x63183030: single_deserializer(abcs.messages.TranslatedText),
  0x3223495b: single_deserializer(abcs.messages.Messages),
  0x54aa7f8e: single_deserializer(abcs.messages.AffectedHistory),
  0x107e31a0: single_deserializer(abcs.messages.Messages),
  0x16fcc2cb: single_deserializer(abcs.AttachMenuBots),
  0x77216192: single_deserializer(abcs.AttachMenuBotsBot),
  0x69f59d69: deserialize_bool,
  0x269dc2c1: single_deserializer(abcs.WebViewResult),
  0xb0d81a83: deserialize_bool,
  0x1a46500a: single_deserializer(abcs.SimpleWebViewResult),
  0xa4314f5: single_deserializer(abcs.WebViewMessageSent),
  0xdc0242c8: single_deserializer(abcs.Updates),
  0x269e9a49: single_deserializer(abcs.messages.TranscribedAudio),
  0x7f1d072f: deserialize_bool,
  0xd9ab0f54: list_deserializer(abcs.Document),
  0xfbfca18f: single_deserializer(abcs.messages.AllStickers),
  0xecf6736: single_deserializer(abcs.messages.FeaturedStickers),
  0x3f64c076: deserialize_bool,
  0xbb8125ba: single_deserializer(abcs.messages.Reactions),
  0x39461db2: single_deserializer(abcs.messages.Reactions),
  0x9dfeefb4: deserialize_bool,
  0x84f80814: single_deserializer(abcs.Updates),
  0x9eb51445: deserialize_bool,
  0x658b7188: single_deserializer(abcs.DefaultHistoryTtl),
  0xfe38d01b: single_deserializer(abcs.Updates),
  0x7488ce5b: single_deserializer(abcs.messages.EmojiGroups),
  0x2ecd56cd: single_deserializer(abcs.messages.EmojiGroups),
  0x21a548f3: single_deserializer(abcs.messages.EmojiGroups),
  0x2c11c0d7: single_deserializer(abcs.EmojiList),
  0xe47cb579: deserialize_bool,
  0x34fdc5c3: single_deserializer(abcs.messages.BotApp),
  0x8c5a3b3c: single_deserializer(abcs.AppWebViewResult),
  0x8ffacae1: single_deserializer(abcs.Updates),
  0xedd4882a: single_deserializer(abcs.updates.State),
  0x19c2f763: single_deserializer(abcs.updates.Difference),
  0x3173d78: single_deserializer(abcs.updates.ChannelDifference),
  0x9e82039: single_deserializer(abcs.photos.Photo),
  0x388a3b5: single_deserializer(abcs.photos.Photo),
  0x87cf7f2f: deserialize_i64_list,
  0x91cd32a8: single_deserializer(abcs.photos.Photos),
  0xe14c4a71: single_deserializer(abcs.photos.Photo),
  0xb304a621: deserialize_bool,
  0xbe5335be: single_deserializer(abcs.upload.File),
  0xde7b673d: deserialize_bool,
  0x24e6818d: single_deserializer(abcs.upload.WebFile),
  0x395f69da: single_deserializer(abcs.upload.CdnFile),
  0x9b2754a8: list_deserializer(abcs.FileHash),
  0x91dc3f31: list_deserializer(abcs.FileHash),
  0x9156982a: list_deserializer(abcs.FileHash),
  0xc4f9186b: single_deserializer(abcs.Config),
  0x1fb33026: single_deserializer(abcs.NearestDc),
  0x522d5a7d: single_deserializer(abcs.help.AppUpdate),
  0x4d392343: single_deserializer(abcs.help.InviteText),
  0x9cdf08cd: single_deserializer(abcs.help.Support),
  0x9010ef6f: single_deserializer(abcs.Updates),
  0xec22cfcd: deserialize_bool,
  0x52029342: single_deserializer(abcs.CdnConfig),
  0x3dc0f114: single_deserializer(abcs.help.RecentMeUrls),
  0x2ca51fd1: single_deserializer(abcs.help.TermsOfServiceUpdate),
  0xee72f79a: deserialize_bool,
  0x3fedc75f: single_deserializer(abcs.help.DeepLinkInfo),
  0x61e3f854: single_deserializer(abcs.help.AppConfig),
  0x6f02f748: deserialize_bool,
  0xc661ad08: single_deserializer(abcs.help.PassportConfig),
  0xd360e72c: single_deserializer(abcs.help.SupportName),
  0x38a08d3: single_deserializer(abcs.help.UserInfo),
  0x66b91b70: single_deserializer(abcs.help.UserInfo),
  0xc0977421: single_deserializer(abcs.help.PromoData),
  0x1e251c95: deserialize_bool,
  0xf50dbaa1: deserialize_bool,
  0x735787a8: single_deserializer(abcs.help.CountriesList),
  0xb81b93d4: single_deserializer(abcs.help.PremiumPromo),
  0xcc104937: deserialize_bool,
  0x84c1fd4e: single_deserializer(abcs.messages.AffectedMessages),
  0xf44a8315: deserialize_bool,
  0xad8c9a23: single_deserializer(abcs.messages.Messages),
  0x77ced9d0: single_deserializer(abcs.channels.ChannelParticipants),
  0xa0ab6cc6: single_deserializer(abcs.channels.ChannelParticipant),
  0xa7f6bbb: single_deserializer(abcs.messages.Chats),
  0x8736a09: single_deserializer(abcs.messages.ChatFull),
  0x91006707: single_deserializer(abcs.Updates),
  0xd33c8902: single_deserializer(abcs.Updates),
  0x566decd0: single_deserializer(abcs.Updates),
  0xf12e57c9: single_deserializer(abcs.Updates),
  0x10e6bd2c: deserialize_bool,
  0x3514b3de: deserialize_bool,
  0x24b524c5: single_deserializer(abcs.Updates),
  0xf836aa95: single_deserializer(abcs.Updates),
  0x199f3a6c: single_deserializer(abcs.Updates),
  0xc0111fe3: single_deserializer(abcs.Updates),
  0xe63fadeb: single_deserializer(abcs.ExportedMessageLink),
  0x1f69b606: single_deserializer(abcs.Updates),
  0xf8b036af: single_deserializer(abcs.messages.Chats),
  0x96e6cd81: single_deserializer(abcs.Updates),
  0x33ddf480: single_deserializer(abcs.channels.AdminLogResults),
  0xea8ca4f9: deserialize_bool,
  0xeab5dc38: deserialize_bool,
  0x9baa9647: single_deserializer(abcs.Updates),
  0xeabbb94c: single_deserializer(abcs.Updates),
  0x8341ecc0: single_deserializer(abcs.messages.Chats),
  0xf5dad378: single_deserializer(abcs.messages.Chats),
  0x40582bb2: deserialize_bool,
  0x8f38cd1f: single_deserializer(abcs.Updates),
  0x58e63f6d: deserialize_bool,
  0xedd49ef0: single_deserializer(abcs.Updates),
  0x11e831ee: single_deserializer(abcs.messages.InactiveChats),
  0xb290c69: single_deserializer(abcs.Updates),
  0xbeaedb94: deserialize_bool,
  0xec210fbf: single_deserializer(abcs.messages.SponsoredMessages),
  0xdc770ee: single_deserializer(abcs.channels.SendAsPeers),
  0x367544db: single_deserializer(abcs.messages.AffectedHistory),
  0xe4cb9580: single_deserializer(abcs.Updates),
  0x4c2985b6: single_deserializer(abcs.Updates),
  0xb45ced1d: deserialize_bool,
  0x50f24105: deserialize_bool,
  0xa245dd3: deserialize_bool,
  0xa4298b29: single_deserializer(abcs.Updates),
  0xf40c0224: single_deserializer(abcs.Updates),
  0xde560d1: single_deserializer(abcs.messages.ForumTopics),
  0xb0831eb9: single_deserializer(abcs.messages.ForumTopics),
  0xf4dfa185: single_deserializer(abcs.Updates),
  0x6c2d9026: single_deserializer(abcs.Updates),
  0x34435f2d: single_deserializer(abcs.messages.AffectedHistory),
  0x2950a18f: single_deserializer(abcs.Updates),
  0x68f3e4eb: single_deserializer(abcs.Updates),
  0xa850a693: deserialize_bool,
  0x6a6e7854: single_deserializer(abcs.Updates),
  0x18afbc93: deserialize_bool,
  0xaa2769ed: single_deserializer(abcs.DataJson),
  0xe6213f4d: deserialize_bool,
  0x517165a: deserialize_bool,
  0x3d8de0f9: deserialize_bool,
  0xe34c0dd6: list_deserializer(abcs.BotCommand),
  0x4504d54f: deserialize_bool,
  0x9c60eb28: single_deserializer(abcs.BotMenuButton),
  0x788464e1: deserialize_bool,
  0x925ec9ea: deserialize_bool,
  0x10cf3123: deserialize_bool,
  0xdcd914fd: single_deserializer(abcs.bots.BotInfo),
  0x9709b1c2: deserialize_bool,
  0x53ca973: deserialize_bool,
  0x1359f4e6: deserialize_bool,
  0xf132e3ef: single_deserializer(abcs.Updates),
  0x87fc5e7: single_deserializer(abcs.DataJson),
  0x37148dbb: single_deserializer(abcs.payments.PaymentForm),
  0x2478d1cc: single_deserializer(abcs.payments.PaymentReceipt),
  0xb6c8f12b: single_deserializer(abcs.payments.ValidatedRequestedInfo),
  0x2d03522f: single_deserializer(abcs.payments.PaymentResult),
  0x227d824b: single_deserializer(abcs.payments.SavedInfo),
  0xd83d70c1: deserialize_bool,
  0x2e79d779: single_deserializer(abcs.payments.BankCardData),
  0xf91b065: single_deserializer(abcs.payments.ExportedInvoice),
  0x80ed747d: single_deserializer(abcs.Updates),
  0xdffd50d3: single_deserializer(abcs.Updates),
  0x9fc19eb6: deserialize_bool,
  0x9021ab67: single_deserializer(abcs.messages.StickerSet),
  0xf7760f51: single_deserializer(abcs.messages.StickerSet),
  0xffb6d4ca: single_deserializer(abcs.messages.StickerSet),
  0x8653febe: single_deserializer(abcs.messages.StickerSet),
  0xa76a5392: single_deserializer(abcs.messages.StickerSet),
  0x284b3639: deserialize_bool,
  0x4dafc503: single_deserializer(abcs.stickers.SuggestedShortName),
  0xf5537ebc: single_deserializer(abcs.messages.StickerSet),
  0x124b1c00: single_deserializer(abcs.messages.StickerSet),
  0x87704394: deserialize_bool,
  0x55451fa9: single_deserializer(abcs.DataJson),
  0x42ff96ed: single_deserializer(abcs.phone.PhoneCall),
  0x3bd2b4a0: single_deserializer(abcs.phone.PhoneCall),
  0x2efe1722: single_deserializer(abcs.phone.PhoneCall),
  0x17d54f61: deserialize_bool,
  0xb2cbc1c0: single_deserializer(abcs.Updates),
  0x59ead627: single_deserializer(abcs.Updates),
  0x277add7e: deserialize_bool,
  0xff7a9383: deserialize_bool,
  0x48cdc6d8: single_deserializer(abcs.Updates),
  0xb132ff7b: single_deserializer(abcs.Updates),
  0x500377f9: single_deserializer(abcs.Updates),
  0x7b393160: single_deserializer(abcs.Updates),
  0x7a777135: single_deserializer(abcs.Updates),
  0x74bbb43d: single_deserializer(abcs.Updates),
  0x41845db: single_deserializer(abcs.phone.GroupCall),
  0xc558d8ab: single_deserializer(abcs.phone.GroupParticipants),
  0xb59cf977: deserialize_i32_list,
  0xf128c708: single_deserializer(abcs.Updates),
  0xa5273abf: single_deserializer(abcs.Updates),
  0x1ca6ac0a: single_deserializer(abcs.Updates),
  0xef7c213a: single_deserializer(abcs.phone.JoinAsPeers),
  0xe6aa647f: single_deserializer(abcs.phone.ExportedGroupCallInvite),
  0x219c34e6: single_deserializer(abcs.Updates),
  0x5680e342: single_deserializer(abcs.Updates),
  0x575e1f8c: deserialize_bool,
  0xcbea6bc4: single_deserializer(abcs.Updates),
  0x1c50d144: single_deserializer(abcs.Updates),
  0x1ab21940: single_deserializer(abcs.phone.GroupCallStreamChannels),
  0xdeb3abbf: single_deserializer(abcs.phone.GroupCallStreamRtmpUrl),
  0x41248786: deserialize_bool,
  0xf2f2330a: single_deserializer(abcs.LangPackDifference),
  0xefea3803: list_deserializer(abcs.LangPackString),
  0xcd984aa5: single_deserializer(abcs.LangPackDifference),
  0x42c6978f: list_deserializer(abcs.LangPackLanguage),
  0x6a596502: single_deserializer(abcs.LangPackLanguage),
  0x6847d0ab: single_deserializer(abcs.Updates),
  0xab42441a: single_deserializer(abcs.stats.BroadcastStats),
  0x621d5fa0: single_deserializer(abcs.StatsGraph),
  0xdcdf8607: single_deserializer(abcs.stats.MegagroupStats),
  0x5630281b: single_deserializer(abcs.messages.Messages),
  0xb6e0a3f5: single_deserializer(abcs.stats.MessageStats),
  0x8472478e: single_deserializer(abcs.chatlists.ExportedChatlistInvite),
  0x719c5c5e: deserialize_bool,
  0x653db63d: single_deserializer(abcs.ExportedChatlistInvite),
  0xce03da83: single_deserializer(abcs.chatlists.ExportedInvites),
  0x41c10fff: single_deserializer(abcs.chatlists.ChatlistInvite),
  0xa6b1e39a: single_deserializer(abcs.Updates),
  0x89419521: single_deserializer(abcs.chatlists.ChatlistUpdates),
  0xe089f8f5: single_deserializer(abcs.Updates),
  0x66e486fb: deserialize_bool,
  0xfdbcd714: list_deserializer(abcs.Peer),
  0x74fae13a: single_deserializer(abcs.Updates),
  0xc7dfdfdd: deserialize_bool,
  0xbcb73644: single_deserializer(abcs.Updates),
  0xb583ba46: single_deserializer(abcs.Updates),
  0xae59db5f: deserialize_i32_list,
  0x9a75a1ef: deserialize_i32_list,
  0xeeb0d625: single_deserializer(abcs.stories.AllStories),
  0x5821a5dc: single_deserializer(abcs.stories.Stories),
  0xb4352016: single_deserializer(abcs.stories.Stories),
  0x5774ca74: single_deserializer(abcs.stories.Stories),
  0x7c2557c4: deserialize_bool,
  0xa556dac8: deserialize_i32_list,
  0xb2028afb: deserialize_bool,
  0x7ed23c57: single_deserializer(abcs.stories.StoryViewsList),
  0x28e16cc8: single_deserializer(abcs.stories.StoryViews),
  0x7b8def20: single_deserializer(abcs.ExportedStoryLink),
  0x1923fa8c: deserialize_bool,
  0x57bbd166: single_deserializer(abcs.Updates),
  0x7fd736b2: single_deserializer(abcs.Updates),
  0x2c4ada50: single_deserializer(abcs.stories.PeerStories),
  0x9b5ae7f9: single_deserializer(abcs.Updates),
  0x535983c3: deserialize_i32_list,
  0xa56a8b60: single_deserializer(abcs.messages.Chats),
  0xbd0415c4: deserialize_bool,
  0x4c449472: single_deserializer(abcs.stories.BoostsStatus),
  0x337ef980: single_deserializer(abcs.stories.BoostersList),
  0xdb05c1bd: single_deserializer(abcs.stories.CanApplyBoostResult),
  0xf29d7c2b: deserialize_bool,
}
__all__ = ['LAYER', 'TYPE_MAPPING', 'RESPONSE_MAPPING']
